@@ -147,6 +147,12 @@ CREATE TABLE IF NOT EXISTS nrens (
     -- The timeout in minutes, after which Confusa will ask for reauthentication
     -- upon sensitive actions.
     reauth_timeout INT DEFAULT 10,
+
+    -- Message (and mode-switch) to allow an NREN-admin to place the
+    -- portal (for the given NREN only) in maintenance-mode.
+    maint_msg TEXT DEFAULT "",
+    maint_mode ENUM('y','n') DEFAULT 'n',
+
     FOREIGN KEY(login_account) REFERENCES account_map(account_map_id) ON DELETE SET NULL
 ) engine=InnoDB;
 
@@ -262,7 +268,9 @@ CREATE TABLE csr_cache (
        -- for the challenge-response cycle. when we ask the user to approve
        -- the system will generate a one-time password and encrypt it with the
        -- uploaded public-key.
-       auth_key char(40) UNIQUE NOT NULL
+       auth_key char(40) UNIQUE NOT NULL,
+       -- the format of the CSR
+       type ENUM('spkac','pkcs10') DEFAULT 'pkcs10'
 ) engine=InnoDB;
 
 -- ---------------------------------------------------------
@@ -343,7 +351,7 @@ CREATE TABLE IF NOT EXISTS admins (
        FOREIGN KEY(nren) REFERENCES nrens(nren_id) ON DELETE CASCADE
 ) engine=InnoDB;
 
- 
+
 -- ---------------------------------------------------------
 --
 -- user_crls
