@@ -47,6 +47,7 @@ class Framework {
 	private $contentPage;
 	private $tpl;
 	private $renderError = false;
+	private static $framework;
 	private static $errors = array();
 	private static $messages = array();
 	private static $warnings = array();
@@ -66,7 +67,7 @@ class Framework {
 			echo "You do not have a valid configuration. Please edit the confusa_config.php properly first<BR>\n";
 			exit(0);
 		}
-
+		self::$framework = $this;
 		/* is the connection running over SSL? */
 		if (!(array_key_exists('HTTPS', $_SERVER) || array_key_exists('https', $_SERVER)) ||
 		    strtolower($_SERVER['HTTPS']) != "on") {
@@ -167,14 +168,23 @@ class Framework {
 
 						$msg .= "<br />\n";
 						$msg .= $this->contentPage->translateMessageTag('fw_error_entitlement_unset_3');
-						$msg .= "<br /><ul>\n<li>";
+						$msg .= '<br /><ul><li style="margin: 1em 0 0 2em">';
 
 						$msg .= $this->contentPage->translateMessageTag('fw_error_entitlement_unset_4');
-						$msg .= "<a href=\"mailto:$email\">$email</a></li>\n<li>";
+						$msg .= "<a href=\"mailto:$email\">$email</a></li>";
+						$msg .= '<li style="margin: 1em 0 0 2em">';
 						$msg .= $this->contentPage->translateMessageTag('fw_error_entitlement_unset_5');
 						$msg .= "<a href=\"$url\">$url</a></li>\n</ul><br />\n";
 					}
 					Framework::error_output($msg);
+				} else {
+					$entitlement = Config::get_config('entitlement_namespace') . ":";
+					$entitlement = Config::get_config('entitlement_user');
+					$msg = $this->contentPage->translateMessageTag('fw_error_entitlement_unset_1');
+					$msg .= "<br /><i>$entitlement</i><br /><br />";
+					$msg .= $this->contentPage->translateMessageTag('fw_error_entitlement_unset_6');
+
+					Framework::warning_output($msg);
 				}
 			}
 		} else {
@@ -196,6 +206,11 @@ class Framework {
 	 * Some actions are more sensitive than others. This function will
 	 * notify the framework that the user should be AuthN recently. The
 	 * limit is configurable.
+	 *
+	 * @param	void
+	 * @return	void
+	 * @access	public
+	 * @static
 	 */
 	public static function sensitive_action()
 	{
@@ -204,6 +219,20 @@ class Framework {
 
 	public function start()
 	{
+		/* From OWASP (prevent clickjacking):
+		 *
+		 * This new (nonstandard) X-FRAME-OPTIONS header is used to mark
+		 * responses that shouldn't be framed. There are two options with
+		 * X-FRAME-OPTIONS. The first is DENY, which prevents everyone from
+		 * framing the content.
+		 *
+		 * This can also be done by apache itself:
+		 * a2enmod headers
+		 * Add to the Virtualhost, directory that hosts confusa:
+		 * Header set X-Frame-Options "DENY"
+		 */
+		header('X-Frame-Options: DENY');
+
 		/* Set tpl object to content page */
 		$this->contentPage->setTpl($this->tpl);
 
@@ -213,7 +242,7 @@ class Framework {
 		try {
 			$this->authenticate();
 		} catch (CGE_CriticalAttributeException $cae) {
-			$msg .= "<b>" . $this->contentPage->translateMessageTag('fw_error_critical_attribute1') . "</b><br /><br />";
+			$msg  = "<b>" . $this->contentPage->translateMessageTag('fw_error_critical_attribute1') . "</b><br /><br />";
 			$msg .= htmlentities($cae->getMessage()) . "<br /><br />";
 			$msg .= $this->contentPage->translateMessageTag('fw_error_critical_attribute2');
 			Framework::error_output($msg);
@@ -280,6 +309,13 @@ class Framework {
 			$this->renderError = true;
 		}
 
+		/* ----------------------------------------------------------------
+		 * Admin messages, trigger on missing elements
+		 */
+		if ($this->person->isNRENAdmin()) {
+			$this->triggerAdminIssues();
+		}
+
 		/* Mode-hook, to catch mode-change regardless of target-page (not only
 		 * index) */
 		if (isset($_GET['mode'])) {
@@ -290,6 +326,7 @@ class Framework {
 			$this->person->setMode($new_mode);
 		}
 
+		$this->tpl->assign('title_logo', $this->contentPage->translateMessageTag('l10n_title_logo'));
 		$this->tpl->assign('person',	$this->person);
 		$this->tpl->assign('subscriber',$this->person->getSubscriber());
 		$this->tpl->assign('nren',	$this->person->getNREN());
@@ -352,11 +389,12 @@ class Framework {
 		$this->tpl->assign('warnings', self::$warnings);
 
 		if (Config::get_config('debug')) {
-			$res .= "<address>\n";
-			$res .= "During this session, we had ";
-			$res .= MDB2Wrapper::getConnCounter() . " individual DB-connections.<br />\n";
-			$res .= "</address>\n";
-			$this->tpl->assign('db_debug', $res);
+			$db_debug_res = "";
+			$db_debug_res .= "<address>\n";
+			$db_debug_res .= "During this session, we had ";
+			$db_debug_res .= MDB2Wrapper::getConnCounter() . " individual DB-connections.<br />\n";
+			$db_debug_res .= "</address>\n";
+			$this->tpl->assign('db_debug', $db_debug_res);
 		}
 		$this->tpl->display('site.tpl');
 
@@ -401,12 +439,12 @@ class Framework {
 			$customPortalTitle = $nren->getCustomPortalTitle();
 
 			if (isset($customPortalTitle)) {
-				$this->tpl->assign('system_title', $customPortalTitle);
+				$this->tpl->assign('system_title', '&nbsp;' .  $customPortalTitle);
 			} else {
-				$this->tpl->assign('system_title', Config::get_config('system_title'));
+				$this->tpl->assign('system_title', '&nbsp;' .  Config::get_config('system_title'));
 			}
 		} else {
-			$this->tpl->assign('system_title', '&nbsp;');
+			$this->tpl->assign('system_title', '');
 		}
 	} /* end applyNRENBranding */
 
@@ -425,56 +463,72 @@ class Framework {
 	{
 		if (!empty($_GET) || !empty($_POST)) {
 			$facsrft = null;
+
 			if (isset($_GET) && array_key_exists('anticsrf', $_GET)) {
 				$facsrft = Input::sanitizeAntiCSRFToken($_GET['anticsrf']);
 			} else if (isset($_POST) && array_key_exists('anticsrf', $_POST)) {
 				$facsrft = Input::sanitizeAntiCSRFToken($_POST['anticsrf']);
+			} else if (isset($_GET) && array_key_exists('return', $_GET)) {
+				/* handle SSP redirect to idp_select */
+				$res = self::getCSRFRandToken(urldecode(urldecode($_GET['return'])));
+				if (is_array($res)) {
+					$facsrft = $res['full'];
+				}
 			}
-
 			if (!self::validateACSRFT($facsrft)) {
 				$msg =  "Got a GET/POST request without the correct anticsrf tag.";
+				$msg .= "Supplied: $facsrft";
 				if (array_key_exists('HTTP_REFERER', $_SERVER)) {
 					$msg .= " Referer was " . $_SERVER['HTTP_REFERER'];
 				}
 				Logger::log_event(LOG_WARNING, "[Anti CSRF] $msg");
 				return true;
 			}
-
-			/* If start_login is set, referer will be another server
-			 * (the IdP), so stop testing here */
-			if (array_key_exists('start_login', $_GET)) {
-				if (Input::sanitizeText($_GET['start_login']) == "yes") {
-					return false;
-				}
-			}
-
-			/* Not a direct CSRF, but verify the HTTP_REFERER to
-			 * avoid replay attacks of the token if it is somehow
-			 * leaked
-			 */
-			if (array_key_exists('HTTP_REFERER', $_SERVER)) {
-				$url  = Input::sanitizeURL("http" . (($_SERVER['HTTPS'] == 'on') ? "s" : "").
-							   "://" . $_SERVER['HTTP_HOST'] .
-							   $_SERVER['SCRIPT_NAME']);
-				$rurl = Input::sanitizeURL(Input::sanitizeURL($_SERVER['HTTP_REFERER']));
-
-				/* Strip out all GET-params in the URL and the pagename */
-				$p = strpos($rurl, "?");
-				if ($p) {
-					$rurl = substr($rurl, 0, $p);
-				}
-				$url  = substr($url , 0, strrpos($url , "/") + 1);
-				$rurl = substr($rurl, 0, strrpos($rurl, "/") + 1);
-				if ($url !== $rurl) {
-					Logger::log_event(LOG_ALERT, "[Anti CSRF] Got correct anti-csrf from client, but HTTP_REFERER was set." .
-							  "Got $rurl, expected $url. Possible CSRF attempt. Request was blocked.");
-					return true;
-				}
-			}
 		}
-		return false; /* no detectable CSRF attempt */
+		/* no detectable CSRF attempt */
+		return false;
 	} /* end CSRFAttempt() */
 
+	/**
+	 * triggerAdminIssues() - post error-messages
+	 *
+	 * Function will report issues in the form of errors to the screen when an
+	 * admin looks at the portal and something is amiss. This includes:
+	 *
+	 * - missing privacy notice for the NREN
+	 * - missing about_nren text
+	 * - incomplete or missing attribute-map
+	 *
+	 * @param	void
+	 * @return	void
+	 * @access	private
+	 */
+	private function triggerAdminIssues()
+	{
+		if (!isset($this->person))
+			return;
+		$nren = $this->person->getNREN();
+		if (!$nren)
+			return;
+
+		$url_arg = "?mode=admin&amp;show=text&amp;anticsrf=".Framework::getAntiCSRF();
+
+		if (!$nren->hasHelpText()) {
+			Framework::warning_output("Missing NREN help-text. <a href=\"stylist.php" .
+									  $url_arg . "#edit_help\">Configure</a>");
+		}
+
+		if (!$nren->hasAboutText()) {
+			Framework::warning_output("Missing About-NREN text. <a href=\"stylist.php".
+									  $url_arg . "#edit_about\">Configure</a>");
+		}
+
+		if (!$nren->hasPrivacyNotice()) {
+			Framework::warning_output("Missing privacy-notice. <a href=\"stylist.php" .
+									  $url_arg . "#edit_pn\">Configure</a>");
+		}
+	} /* end triggerAdminIssues() */
+
 	/**
 	 * Register new error-message to display in the page
 	 *
@@ -535,10 +589,21 @@ class Framework {
 		}
 		/* make sure rand only contains allowed characters. */
 		$rand = Input::sanitizeAntiCSRFToken($rand);
-
 		return $rand.":".sha1(session_id().$rand);
 	} /* end getAntiCSRF() */
 
+	private static function getCSRFRandToken($token)
+	{
+		$token = substr($token, strpos($token, 'anticsrf') + strlen('anticsrf') + 1 );
+		$pos = strrpos($token, ":");
+		if ($pos===false) {
+			/* echo $token;  */
+			return false;
+		}
+		return array('rand' => substr($token, 0, $pos),
+					 'csrf' => substr($token, $pos +1),
+					 'full' => $token);
+	}
 
 	/**
 	 * validateACSRFT() validate a supplied token
@@ -562,4 +627,13 @@ class Framework {
 		return $token === self::getAntiCSRF(substr($token, 0, $pos));
 	} /* end validateACSRFT() */
 
+	public static function get()
+	{
+		if (!is_null(self::$framework))
+			return self::$framework;
+		return null;
+	}
+
 } /* end class Framework */
+
+?>
\ No newline at end of file
